@@ -65,7 +65,7 @@ class TestInstaller(ITestInstaller):
             if observer:
                 observer.about_to_install_packages(self.deps)
             # XXX: Possible point of target-specific package installation
-            cmd = "sudo apt-get install -y --force-yes " + " ".join(self.deps)
+            cmd = "sudo DEBIAN_FRONTEND=noninteractive apt-get install -y --force-yes " + " ".join(self.deps)
             self._run_shell_cmd(cmd, observer)
             if observer:
                 observer.did_install_packages(self.deps)
