@@ -18,6 +18,7 @@ from lava_test.core.config import get_config
 
 import logging
 
+
 class TestLoader(object):
     """
     Test loader.
@@ -53,11 +54,11 @@ class TestLoader(object):
                 raise RuntimeError(
                     "lava-test is not properly set up."
                     " Please read the README file")
-            except ImportError, err:
-                logging.warning("Couldn't load module : %s . Maybe configuration needs to be updated" % module_name)
-                logging.warning("The configuration is stored at %s" %(get_config().configdir))
-
-
+            except ImportError:
+                logging.warning("Couldn't load module: %s", module_name)
+                logging.warning(
+                    "The configuration may need updating, it is stored in %r",
+                    get_config().configdir)
 
     def __getitem__(self, test_id):
         """
