@@ -1,5 +1,4 @@
-
-# Copyright (c) 2010, 2011, 2012  Linaro
+# Copyright (c) 2010-2012  Linaro
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,8 +14,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
-gatortests  - tests for streamline gator driver and daemon
-^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+gatortests - tests for streamline gator driver and daemon
 
 """
 
@@ -25,17 +23,20 @@ from lava_test.core.parsers import TestParser
 from lava_test.core.runners import TestRunner
 from lava_test.core.tests import Test
 
+INSTALLSTEPS = ['']
+DEPS = ['gatortests']
 
-INSTALLSTEPS = ['bzr branch lp:~stubbsdm/+junk/gator-tests']
-RUNSTEPS = ["python gator-tests/gatortests.py"]
-PATTERN = "^\*\*\*(?P<test_case_id>\w+):\s(?P<result>\w+)\*\*\*"
-
-
+RUNSTEPS = ["gatortests"]
 DEFAULT_OPTIONS = ""
 
-installer = TestInstaller(INSTALLSTEPS, deps=["python"])
+PATTERN = "^\*\*\*(?P<test_case_id>\w+):\s(?P<result>\w+)\*\*\*"
+
+installer = TestInstaller(INSTALLSTEPS, deps=DEPS)
 runner = TestRunner(RUNSTEPS,default_options=DEFAULT_OPTIONS)
 parser = TestParser(pattern=PATTERN)
-testobj = Test(test_id="gatortests", installer=installer,runner=runner, parser=parser)
-
 
+testobj = Test(
+    test_id="gatortests",
+    installer=installer,
+    runner=runner,
+    parser=parser)
