@@ -29,7 +29,7 @@ from lava_test.core.runners import TestRunner
 from lava_test.core.tests import Test
 
 INSTALLSTEPS = ['git clone git://igloocommunity.org/git/testing/snowball-ltp-tests.git',
-                'cd snowball-ltp-tests; make tests; make install']
+                'cd snowball-ltp-tests; make config; make tests; make install']
 
 DEPS = ['git-core', 'make', 'build-essential']
 
